"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CssVars = exports.useInitCssVars = exports.ANIMATION_TIME = void 0;

var _react = require("react");

const ANIMATION_TIME = 0.5; // in seconds

exports.ANIMATION_TIME = ANIMATION_TIME;
var CssVar;

(function (CssVar) {
  CssVar["DURATION"] = "--s-trans-dur";
  CssVar["ANIMATION"] = "--s-trans-animation";
  CssVar["WIDTH"] = "--s-width";
  CssVar["TRANSFORM_X"] = "--s-transform-x";
  CssVar["AMOUNT"] = "--s-amount";
})(CssVar || (CssVar = {}));

const _set = ({
  current
}, name, value) => {
  if (current) {
    current.style.setProperty(name, value);
  }
}; // should be in [0, 2]
// where 0 means left end, 1 means center and 2 the right end


const _setX = ({
  current
}, value = 0, factor) => {
  if (current) {
    current.style.setProperty(CssVar.WIDTH, `${current.clientWidth}`);
    current.style.setProperty(CssVar.TRANSFORM_X, `${-current.clientWidth * factor + value}`);
  }
};

const goTo = (ref, factor) => {
  _set(ref, CssVar.DURATION, `${ANIMATION_TIME}s`);

  _setX(ref, 0, factor);
};

const update = (ref, value) => _setX(ref, value, 1);

const amount = (ref, value) => _set(ref, CssVar.AMOUNT, String(value));

const animation = (ref, value = 'ease-out') => _set(ref, CssVar.ANIMATION, value);

const finish = ref => {
  _set(ref, CssVar.DURATION, '0');

  _setX(ref, 0, 1);
};
/**
 * eFactor (effective factor) is between [-1, 1] to page the slider.
 */


const transition = (ref, eFactor, noAnimation) => {
  if (noAnimation) return Promise.resolve(finish(ref));
  CssVars.goTo(ref, eFactor + 1);
  return new Promise(resolve => {
    setTimeout(() => {
      finish(ref);
      resolve();
    }, 1000 * ANIMATION_TIME);
  });
};

const useInitCssVars = (ref, amount, animation) => {
  // useLayoutEffect(() => finish(ref), []); // eslint-disable-line react-hooks/exhaustive-deps
  (0, _react.useLayoutEffect)(() => {
    CssVars.amount(ref, amount);
  }, [amount]); // eslint-disable-line react-hooks/exhaustive-deps

  (0, _react.useLayoutEffect)(() => {
    CssVars.animation(ref, animation);
  }, [animation]); // eslint-disable-line react-hooks/exhaustive-deps
};

exports.useInitCssVars = useInitCssVars;
const CssVars = {
  goTo,
  finish,
  update,
  transition,
  amount,
  animation
};
exports.CssVars = CssVars;