"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAutoSlide = exports.NoopAutoSlider = void 0;

var _react = require("react");

const NoopAutoSlider = {
  start: () => {},
  stop: () => {}
};
exports.NoopAutoSlider = NoopAutoSlider;
const noTimer = 0;

const createAutoSlider = (next, autoSlide) => {
  let id = noTimer;
  if (!autoSlide) return NoopAutoSlider;else return {
    start: () => {
      if (!id) {
        id = setInterval(next, autoSlide);
      }
    },
    stop: () => {
      clearInterval(id);
      id = noTimer;
    }
  };
};

const useAutoSlide = (next, autoSlide) => {
  const autoSlider = (0, _react.useMemo)(() => createAutoSlider(next, autoSlide), [next, autoSlide]);
  (0, _react.useEffect)(() => {
    autoSlider.start();
    return autoSlider.stop;
  }, [autoSlider]);
  return autoSlider;
};

exports.useAutoSlide = useAutoSlide;