"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.usePaging = void 0;

var _react = require("react");

var _cssVars = require("./css-vars");

var _useNopWhilePending = require("./useNopWhilePending");

const usePaging = (ref, length, amount, noAnimation, onSwipe) => {
  const [pos, setPos] = (0, _react.useState)(0);
  const isLeft = pos === 0;
  const limit = Math.max(0, length - amount);
  const isRight = pos >= limit;
  (0, _react.useEffect)(() => {
    if (pos > limit) setPos(limit);
  }, [amount, pos, limit]);
  const page = (0, _useNopWhilePending.useNopWhilePending)(factor => {
    const nextPos = factor === 1 ? Math.min(limit, pos + amount) : Math.max(0, pos - amount);
    onSwipe == null ? void 0 : onSwipe({
      pos: nextPos,
      diff: nextPos - pos,
      direction: factor
    });
    const eFactor = factor * Math.abs(nextPos - pos) / amount;
    return _cssVars.CssVars.transition(ref, eFactor, noAnimation).then(() => setPos(nextPos));
  });
  const prev = (0, _react.useCallback)(() => page(-1), []); // eslint-disable-line react-hooks/exhaustive-deps

  const next = (0, _react.useCallback)(() => page(1), []); // eslint-disable-line react-hooks/exhaustive-deps

  return [pos, prev, next, isLeft, isRight];
};

exports.usePaging = usePaging;