import React, { forwardRef, useImperativeHandle, useRef } from 'react';
import { useArrangeAfterResize } from './useArrangeAfterResize';
import { useInitCssVars } from './css-vars';
import { StagedDraggable } from './StagedDraggable';
import { useAutoSlide } from './useAutoSlide';
import { useInfinitySlides } from './useInfinitySlides';
import { useInfinityPaging } from './useInfinityPaging';
import { classNames } from './util';
export const InfinityStaged = forwardRef(({
  children,
  amount: _amount = 1,
  hideArrows,
  autoSlide,
  noDrag,
  animation,
  onSwipe,
  className
}, forwardedRef) => {
  const ref = useRef(null);
  const stagedRef = useRef(null);
  useArrangeAfterResize(ref);
  useInitCssVars(ref, _amount, animation);
  const [{
    pos,
    paged
  }, prev, next] = useInfinityPaging(ref, children.length, _amount, animation === 'none', onSwipe); // useSwipeListener(pos, onSwipe);

  const autoSlider = useAutoSlide(next, autoSlide);
  const slides = useInfinitySlides(children, _amount, pos, paged);
  useImperativeHandle(forwardedRef, () => ({
    prev,
    next
  }), []); // eslint-disable-line react-hooks/exhaustive-deps

  return /*#__PURE__*/React.createElement("div", {
    className: classNames('staged-outer', className),
    ref: ref
  }, hideArrows || /*#__PURE__*/React.createElement("div", {
    className: "staged-left-nav",
    onClick: prev
  }), noDrag ? /*#__PURE__*/React.createElement("div", {
    className: "staged",
    ref: stagedRef
  }, slides) : /*#__PURE__*/React.createElement(StagedDraggable, {
    outerRef: ref,
    forwardRef: stagedRef,
    prev: prev,
    next: next,
    slides: slides,
    autoSlider: autoSlider
  }), hideArrows || /*#__PURE__*/React.createElement("div", {
    className: "staged-right-nav",
    onClick: next
  }));
});