import React, { useRef, forwardRef, useImperativeHandle } from 'react';
import { useArrangeAfterResize } from './useArrangeAfterResize';
import { usePaging } from './usePaging';
import { useInitCssVars } from './css-vars';
import { StagedDraggable } from './StagedDraggable';
import { useSlides } from './useSlides';
import { classNames } from './util';
export const Staged = forwardRef(({
  children,
  amount: _amount = 1,
  hideArrows,
  noDrag,
  animation,
  onSwipe,
  className
}, forwardedRef) => {
  const ref = useRef(null);
  const stagedRef = useRef(null);
  useArrangeAfterResize(ref);
  useInitCssVars(ref, _amount, animation);
  const [pos, prev, next, isLeft, isRight] = usePaging(ref, children.length, _amount, animation === 'none', onSwipe);
  const slides = useSlides(children, _amount, pos);
  useImperativeHandle(forwardedRef, () => ({
    prev,
    next
  }), []); // eslint-disable-line react-hooks/exhaustive-deps

  return /*#__PURE__*/React.createElement("div", {
    className: classNames('staged-outer', className),
    ref: ref
  }, hideArrows || isLeft || /*#__PURE__*/React.createElement("div", {
    className: "staged-left-nav",
    onClick: prev
  }), noDrag ? /*#__PURE__*/React.createElement("div", {
    className: "staged",
    ref: stagedRef
  }, slides) : /*#__PURE__*/React.createElement(StagedDraggable, {
    outerRef: ref,
    forwardRef: stagedRef,
    prev: prev,
    next: next,
    slides: slides,
    isLeft: isLeft,
    isRight: isRight
  }), hideArrows || isRight || /*#__PURE__*/React.createElement("div", {
    className: "staged-right-nav",
    onClick: next
  }));
});