import { useEffect, useMemo } from 'react';
export const NoopAutoSlider = {
  start: () => {},
  stop: () => {}
};
const noTimer = 0;

const createAutoSlider = (next, autoSlide) => {
  let id = noTimer;
  if (!autoSlide) return NoopAutoSlider;else return {
    start: () => {
      if (!id) {
        id = setInterval(next, autoSlide);
      }
    },
    stop: () => {
      clearInterval(id);
      id = noTimer;
    }
  };
};

export const useAutoSlide = (next, autoSlide) => {
  const autoSlider = useMemo(() => createAutoSlider(next, autoSlide), [next, autoSlide]);
  useEffect(() => {
    autoSlider.start();
    return autoSlider.stop;
  }, [autoSlider]);
  return autoSlider;
};