import { useCallback, useState } from 'react';
import { CssVars } from './css-vars';
import { modulo } from './util';
import { useNopWhilePending } from './useNopWhilePending';
export const useInfinityPaging = (ref, length, amount, noAnimation, onSwipe) => {
  const [state, setState] = useState({
    pos: 0,
    paged: 0
  });
  const page = useNopWhilePending(factor => {
    const {
      pos,
      paged
    } = state;
    const nextPos = modulo(pos + factor * amount, length);
    onSwipe == null ? void 0 : onSwipe({
      pos: nextPos,
      diff: nextPos - pos,
      direction: factor
    });
    return CssVars.transition(ref, factor, noAnimation).then(() => setState({
      pos: nextPos,
      paged: paged + factor
    }));
  });
  const prev = useCallback(() => page(-1), []); // eslint-disable-line react-hooks/exhaustive-deps

  const next = useCallback(() => page(1), []); // eslint-disable-line react-hooks/exhaustive-deps

  return [state, prev, next];
};