import { useCallback, useState, useEffect } from 'react';
import { CssVars } from './css-vars';
import { useNopWhilePending } from './useNopWhilePending';
export const usePaging = (ref, length, amount, noAnimation, onSwipe) => {
  const [pos, setPos] = useState(0);
  const isLeft = pos === 0;
  const limit = Math.max(0, length - amount);
  const isRight = pos >= limit;
  useEffect(() => {
    if (pos > limit) setPos(limit);
  }, [amount, pos, limit]);
  const page = useNopWhilePending(factor => {
    const nextPos = factor === 1 ? Math.min(limit, pos + amount) : Math.max(0, pos - amount);
    onSwipe == null ? void 0 : onSwipe({
      pos: nextPos,
      diff: nextPos - pos,
      direction: factor
    });
    const eFactor = factor * Math.abs(nextPos - pos) / amount;
    return CssVars.transition(ref, eFactor, noAnimation).then(() => setPos(nextPos));
  });
  const prev = useCallback(() => page(-1), []); // eslint-disable-line react-hooks/exhaustive-deps

  const next = useCallback(() => page(1), []); // eslint-disable-line react-hooks/exhaustive-deps

  return [pos, prev, next, isLeft, isRight];
};